==> leadlink_open_api-0.0.21.tar.gz: lib/api_product_sku.dart <==

part of leadlinkopenapi;

class APIProductSKU {

  // 根据skuId获取产品SKU
  static void getProductSKUById(int skuId,{Function(ProductSKU productSKU) onSucc,Function(String) onFail}) async {

    try {
      
      var queryBuider = QueryBuilder<ProductSKU>(ProductSKU())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('productSkuId', skuId);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      if(resp.results.length == 0) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      ProductSKU sku = resp.results.first;
      if(onSucc != null) onSucc(sku);


    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }

  // 获取所有SKU列表
  static void getProductSKUList({Function(List<ProductSKU> skuList) onSucc,Function(String) onFail}) async {
    
    try {

      var queryBuider = QueryBuilder<ProductSKU>(ProductSKU())
      ..whereNotEqualTo('isActive', false);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      if(onSucc != null) onSucc(resp.results.cast<ProductSKU>());


    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }


  }

  // 提交新的sku 
  static void commitProductSKU(String name,int productId,Map<dynamic,String> skuParam,{Function() onSucc,Function(String) onFail}) {
    
    try {

      // 获取产品
      APIProduct.getProductDetailByProductId(productId,onFail: onFail,onSucc: (product) async {

          final productResp = await ParseObject('Product').getObject(product['objectId']);
          ParseObject prodcutObject = productResp.results.first;

          var cntQuery = QueryBuilder<ParseObject>(ParseObject("Counters"))
          ..whereEqualTo('name', 'ProductSKU');
          var cntResp = await cntQuery.query();
          ParseObject counter = cntResp.results.first;
          
          ParseObject item      = ParseObject('ProductSKU');
          item['name']       = name ?? '';
          item['skuParam']    = skuParam; // 此处需结合acceesType做校验
          item['isActive']      = true;
          item['product']       = prodcutObject;
          item['productSkuId']    = counter['next'];

          await item.save();

          counter.setIncrement('next', 1);
          await counter.save();

          if(onSucc !=null) onSucc();              

        }
      );

    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }
  }

  // 获取所有SKU列表通过产品ID
  static void getProductSKUListByProductId(int productId,{Function(List<ProductSKU> skuList) onSucc,Function(String) onFail}) async {
    
    try {

      var prdQuery = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('productId', productId);

      var queryBuider = QueryBuilder<ProductSKU>(ProductSKU())
      ..whereMatchesQuery('product', prdQuery)
      ..includeObject(['product','product.accessType','product.productCategory'])
      ..whereNotEqualTo('isActive', false);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      if(onSucc != null) onSucc(resp.results.cast<ProductSKU>());


    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }
  }
}

==> leadlink_open_api-0.0.32.tar.gz: lib/api_product_sku.dart <==

part of leadlinkopenapi;

class APIProductSKU {

  // 根据skuId获取产品SKU
  static void getProductSKUById(int skuId,{Function(ProductSKU productSKU) onSucc,Function(String) onFail}) async {

    try {
      
      var queryBuider = QueryBuilder<ProductSKU>(ProductSKU())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('productSkuId', skuId);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      if(resp.results.length == 0) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      ProductSKU sku = resp.results.first;
      if(onSucc != null) onSucc(sku);


    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }

  }

  // 获取所有SKU列表
  static void getProductSKUList({Function(List<ProductSKU> skuList) onSucc,Function(String) onFail}) async {
    
    try {

      var queryBuider = QueryBuilder<ProductSKU>(ProductSKU())
      ..whereNotEqualTo('isActive', false);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      if(onSucc != null) onSucc(resp.results.cast<ProductSKU>());


    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }


  }

  // 提交新的sku 
  static void commitProductSKU(String name,int productId,Map<dynamic,String> skuParam,{Function() onSucc,Function(String) onFail}) {
    
    try {

      // 获取产品
      APIProduct.getProductDetailByProductId(productId,onFail: onFail,onSucc: (product) async {

          final productResp = await ParseObject('Product').getObject(product['objectId']);
          ParseObject prodcutObject = productResp.results.first;

          var cntQuery = QueryBuilder<ParseObject>(ParseObject("Counters"))
          ..whereEqualTo('name', 'ProductSKU');
          var cntResp = await cntQuery.query();
          ParseObject counter = cntResp.results.first;
          
          ParseObject item      = ParseObject('ProductSKU');
          item['name']          = name ?? '';
          item['skuParam']      = skuParam;
          item['isActive']      = true;
          item['product']       = prodcutObject;
          item['productSkuId']  = counter['next'];

          await item.save();

          counter.setIncrement('next', 1);
          await counter.save();

          if(onSucc !=null) onSucc();              

        }
      );

    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }
  }

  // 获取所有SKU列表通过产品ID
  static void getProductSKUListByProductId(int productId,{Function(List<ProductSKU> skuList) onSucc,Function(String) onFail}) async {
    
    try {

      var prdQuery = QueryBuilder<Product>(Product())
      ..whereNotEqualTo('isActive', false)
      ..whereEqualTo('productId', productId);

      var queryBuider = QueryBuilder<ProductSKU>(ProductSKU())
      ..orderByDescending('productSkuId')
      ..whereMatchesQuery('product', prdQuery)
      ..includeObject(['product','product.accessType','product.productCategory'])
      ..whereNotEqualTo('isActive', false);

      var resp = await queryBuider.query();

      if(resp.success == false) {
        if(onFail != null) onFail(APITip.apiFail);
        return;
      }

      if(onSucc != null) onSucc(resp.results.cast<ProductSKU>());


    } catch (e) {
      if(onFail != null) onFail(APITip.apiFail);
      return;
    }
  }
}
